pub struct DefaultRequestProcessor<M, T, N, A = SimpleAgentInfo>where
M: AsyncMessageHandler + Send + Sync + 'static,
T: AsyncTaskManager + Send + Sync + 'static,
N: AsyncNotificationManager + Send + Sync + 'static,
A: AgentInfoProvider + Send + Sync + 'static,{ /* private fields */ }Expand description
Default implementation of a request processor that routes requests to business handlers
Implementations
Sourceimpl<M, T, N, A> DefaultRequestProcessor<M, T, N, A>where
M: AsyncMessageHandler + Send + Sync + 'static,
T: AsyncTaskManager + Send + Sync + 'static,
N: AsyncNotificationManager + Send + Sync + 'static,
A: AgentInfoProvider + Send + Sync + 'static,
impl<M, T, N, A> DefaultRequestProcessor<M, T, N, A>where
M: AsyncMessageHandler + Send + Sync + 'static,
T: AsyncTaskManager + Send + Sync + 'static,
N: AsyncNotificationManager + Send + Sync + 'static,
A: AgentInfoProvider + Send + Sync + 'static,
Sourceimpl<H, A> DefaultRequestProcessor<H, H, H, A>where
H: AsyncMessageHandler + AsyncTaskManager + AsyncNotificationManager + Send + Sync + 'static,
A: AgentInfoProvider + Send + Sync + 'static,
impl<H, A> DefaultRequestProcessor<H, H, H, A>where
H: AsyncMessageHandler + AsyncTaskManager + AsyncNotificationManager + Send + Sync + 'static,
A: AgentInfoProvider + Send + Sync + 'static,
Sourcepub fn with_handler(handler: H, agent_info: A) -> Self
pub fn with_handler(handler: H, agent_info: A) -> Self
Create a new request processor with a single handler that implements all traits