pub struct GetTaskPushNotificationConfigParams {
pub id: String,
pub push_notification_config_id: Option<String>,
pub metadata: Option<Map<String, Value>>,
}Expand description
Parameters for getting a specific push notification config (v0.3.0).
Enhanced version that allows retrieving a specific config by ID, supporting multiple notification callbacks per task.
Fields
id: StringTask ID
push_notification_config_id: Option<String>Specific config ID to retrieve (optional)
metadata: Option<Map<String, Value>>Trait Implementations
Sourceimpl Clone for GetTaskPushNotificationConfigParams
impl Clone for GetTaskPushNotificationConfigParams
Sourcefn clone(&self) -> GetTaskPushNotificationConfigParams
fn clone(&self) -> GetTaskPushNotificationConfigParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for GetTaskPushNotificationConfigParams
impl<'de> Deserialize<'de> for GetTaskPushNotificationConfigParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more