pub struct AgentCardView<'a> {Show 15 fields
pub name: &'a str,
pub description: &'a str,
pub supported_interfaces: RepeatedView<'a, AgentInterfaceView<'a>>,
pub provider: MessageFieldView<AgentProviderView<'a>>,
pub version: &'a str,
pub documentation_url: Option<&'a str>,
pub capabilities: MessageFieldView<AgentCapabilitiesView<'a>>,
pub security_schemes: MapView<'a, &'a str, SecuritySchemeView<'a>>,
pub security_requirements: RepeatedView<'a, SecurityRequirementView<'a>>,
pub default_input_modes: RepeatedView<'a, &'a str>,
pub default_output_modes: RepeatedView<'a, &'a str>,
pub skills: RepeatedView<'a, AgentSkillView<'a>>,
pub signatures: RepeatedView<'a, AgentCardSignatureView<'a>>,
pub icon_url: Option<&'a str>,
pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}Fields
name: &'a strField 1: name
description: &'a strField 2: description
supported_interfaces: RepeatedView<'a, AgentInterfaceView<'a>>Field 3: supported_interfaces
provider: MessageFieldView<AgentProviderView<'a>>Field 4: provider
version: &'a strField 5: version
documentation_url: Option<&'a str>Field 6: documentation_url
capabilities: MessageFieldView<AgentCapabilitiesView<'a>>Field 7: capabilities
security_schemes: MapView<'a, &'a str, SecuritySchemeView<'a>>Field 8: security_schemes (map)
security_requirements: RepeatedView<'a, SecurityRequirementView<'a>>Field 9: security_requirements
default_input_modes: RepeatedView<'a, &'a str>Field 10: default_input_modes
default_output_modes: RepeatedView<'a, &'a str>Field 11: default_output_modes
skills: RepeatedView<'a, AgentSkillView<'a>>Field 12: skills
signatures: RepeatedView<'a, AgentCardSignatureView<'a>>Field 13: signatures
icon_url: Option<&'a str>Field 14: icon_url
__buffa_unknown_fields: UnknownFieldsView<'a>Trait Implementations
Sourceimpl<'a> Clone for AgentCardView<'a>
impl<'a> Clone for AgentCardView<'a>
Sourcefn clone(&self) -> AgentCardView<'a>
fn clone(&self) -> AgentCardView<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for AgentCardView<'a>
impl<'a> Debug for AgentCardView<'a>
Sourceimpl<'a> Default for AgentCardView<'a>
impl<'a> Default for AgentCardView<'a>
Sourcefn default() -> AgentCardView<'a>
fn default() -> AgentCardView<'a>
Returns the “default value” for a type. Read more
Sourceimpl DefaultViewInstance for AgentCardView<'static>
impl DefaultViewInstance for AgentCardView<'static>
Sourcefn default_view_instance() -> &'static Self
fn default_view_instance() -> &'static Self
Return a reference to the single default view instance.
Sourceimpl<'a> HasDefaultViewInstance for AgentCardView<'a>
impl<'a> HasDefaultViewInstance for AgentCardView<'a>
Sourcetype Static = AgentCardView<'static>
type Static = AgentCardView<'static>
The
'static instantiation of this view type.Sourcefn default_view_ptr() -> *const u8
fn default_view_ptr() -> *const u8
Return a pointer to the static default instance, erasing the
lifetime so it can be used for any
'a.Sourceimpl<'a> MessageView<'a> for AgentCardView<'a>
impl<'a> MessageView<'a> for AgentCardView<'a>
Sourcefn to_owned_message(&self) -> AgentCard
fn to_owned_message(&self) -> AgentCard
Convert this view to the owned message type.
Sourcefn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
fn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
Decode a view from a buffer, borrowing string/bytes fields directly. Read more
Sourcefn decode_view_with_limit(
buf: &'a [u8],
depth: u32,
) -> Result<Self, DecodeError>
fn decode_view_with_limit( buf: &'a [u8], depth: u32, ) -> Result<Self, DecodeError>
Decode a view with a custom recursion depth limit. Read more