pub struct AgentSkill {
pub id: String,
pub name: String,
pub description: String,
pub tags: Vec<String>,
pub examples: Vec<String>,
pub input_modes: Vec<String>,
pub output_modes: Vec<String>,
pub security_requirements: Vec<SecurityRequirement>,
/* private fields */
}Fields
id: StringField 1: id
name: StringField 2: name
description: StringField 3: description
Field 4: tags
examples: Vec<String>Field 5: examples
input_modes: Vec<String>Field 6: input_modes
output_modes: Vec<String>Field 7: output_modes
security_requirements: Vec<SecurityRequirement>Field 8: security_requirements
Implementations
Sourceimpl AgentSkill
impl AgentSkill
Sourcepub fn new(
id: String,
name: String,
description: String,
tags: Vec<String>,
) -> Self
pub fn new( id: String, name: String, description: String, tags: Vec<String>, ) -> Self
Create a new skill with the minimum required fields
Sourcepub fn with_examples(self, examples: Vec<String>) -> Self
pub fn with_examples(self, examples: Vec<String>) -> Self
Add examples to the skill
Sourcepub fn with_input_modes(self, input_modes: Vec<String>) -> Self
pub fn with_input_modes(self, input_modes: Vec<String>) -> Self
Add input modes to the skill
Sourcepub fn with_output_modes(self, output_modes: Vec<String>) -> Self
pub fn with_output_modes(self, output_modes: Vec<String>) -> Self
Add output modes to the skill
Sourcepub fn with_security(self, security: Vec<HashMap<String, Vec<String>>>) -> Self
pub fn with_security(self, security: Vec<HashMap<String, Vec<String>>>) -> Self
Add security requirements to the skill
Sourcepub fn comprehensive(
id: String,
name: String,
description: String,
tags: Vec<String>,
examples: Option<Vec<String>>,
input_modes: Option<Vec<String>>,
output_modes: Option<Vec<String>>,
security: Option<Vec<HashMap<String, Vec<String>>>>,
) -> Self
pub fn comprehensive( id: String, name: String, description: String, tags: Vec<String>, examples: Option<Vec<String>>, input_modes: Option<Vec<String>>, output_modes: Option<Vec<String>>, security: Option<Vec<HashMap<String, Vec<String>>>>, ) -> Self
Create a comprehensive skill with all details in one call