pub struct Message {
pub message_id: String,
pub context_id: String,
pub task_id: String,
pub role: EnumValue<Role>,
pub parts: Vec<Part>,
pub metadata: MessageField<Struct>,
pub extensions: Vec<String>,
pub reference_task_ids: Vec<String>,
/* private fields */
}Fields
message_id: StringField 1: message_id
context_id: StringField 2: context_id
task_id: StringField 3: task_id
role: EnumValue<Role>Field 4: role
parts: Vec<Part>Field 5: parts
metadata: MessageField<Struct>Field 6: metadata
extensions: Vec<String>Field 7: extensions
reference_task_ids: Vec<String>Field 8: reference_task_ids
Implementations
Sourceimpl Message
impl Message
Sourcepub fn builder() -> MessageBuilder
pub fn builder() -> MessageBuilder
Create a new Message builder
Sourcepub fn user_text(text: String, message_id: String) -> Self
pub fn user_text(text: String, message_id: String) -> Self
Create a new user message with a single text part
Sourcepub fn agent_text(text: String, message_id: String) -> Self
pub fn agent_text(text: String, message_id: String) -> Self
Create a new agent message with a single text part