pub struct PartView<'a> {
pub metadata: MessageFieldView<StructView<'a>>,
pub filename: &'a str,
pub media_type: &'a str,
pub content: Option<ContentView<'a>>,
pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}Fields
metadata: MessageFieldView<StructView<'a>>Field 5: metadata
filename: &'a strField 6: filename
media_type: &'a strField 7: media_type
content: Option<ContentView<'a>>__buffa_unknown_fields: UnknownFieldsView<'a>Trait Implementations
Sourceimpl DefaultViewInstance for PartView<'static>
impl DefaultViewInstance for PartView<'static>
Sourcefn default_view_instance() -> &'static Self
fn default_view_instance() -> &'static Self
Return a reference to the single default view instance.
Sourceimpl<'a> HasDefaultViewInstance for PartView<'a>
impl<'a> HasDefaultViewInstance for PartView<'a>
Sourceimpl<'a> MessageView<'a> for PartView<'a>
impl<'a> MessageView<'a> for PartView<'a>
Sourcefn to_owned_message(&self) -> Part
fn to_owned_message(&self) -> Part
Convert this view to the owned message type.
Sourcefn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
fn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
Decode a view from a buffer, borrowing string/bytes fields directly. Read more
Sourcefn decode_view_with_limit(
buf: &'a [u8],
depth: u32,
) -> Result<Self, DecodeError>
fn decode_view_with_limit( buf: &'a [u8], depth: u32, ) -> Result<Self, DecodeError>
Decode a view with a custom recursion depth limit. Read more