pub struct SecurityRequirementView<'a> {
pub schemes: MapView<'a, &'a str, StringListView<'a>>,
pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}Fields
schemes: MapView<'a, &'a str, StringListView<'a>>Field 1: schemes (map)
__buffa_unknown_fields: UnknownFieldsView<'a>Trait Implementations
Sourceimpl<'a> Clone for SecurityRequirementView<'a>
impl<'a> Clone for SecurityRequirementView<'a>
Sourcefn clone(&self) -> SecurityRequirementView<'a>
fn clone(&self) -> SecurityRequirementView<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for SecurityRequirementView<'a>
impl<'a> Debug for SecurityRequirementView<'a>
Sourceimpl<'a> Default for SecurityRequirementView<'a>
impl<'a> Default for SecurityRequirementView<'a>
Sourcefn default() -> SecurityRequirementView<'a>
fn default() -> SecurityRequirementView<'a>
Returns the “default value” for a type. Read more
Sourceimpl DefaultViewInstance for SecurityRequirementView<'static>
impl DefaultViewInstance for SecurityRequirementView<'static>
Sourcefn default_view_instance() -> &'static Self
fn default_view_instance() -> &'static Self
Return a reference to the single default view instance.
Sourceimpl<'a> HasDefaultViewInstance for SecurityRequirementView<'a>
impl<'a> HasDefaultViewInstance for SecurityRequirementView<'a>
Sourcetype Static = SecurityRequirementView<'static>
type Static = SecurityRequirementView<'static>
The
'static instantiation of this view type.Sourcefn default_view_ptr() -> *const u8
fn default_view_ptr() -> *const u8
Return a pointer to the static default instance, erasing the
lifetime so it can be used for any
'a.Sourceimpl<'a> MessageView<'a> for SecurityRequirementView<'a>
impl<'a> MessageView<'a> for SecurityRequirementView<'a>
Sourcefn to_owned_message(&self) -> SecurityRequirement
fn to_owned_message(&self) -> SecurityRequirement
Convert this view to the owned message type.
Sourcetype Owned = SecurityRequirement
type Owned = SecurityRequirement
The corresponding owned message type.
Sourcefn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
fn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
Decode a view from a buffer, borrowing string/bytes fields directly. Read more
Sourcefn decode_view_with_limit(
buf: &'a [u8],
depth: u32,
) -> Result<Self, DecodeError>
fn decode_view_with_limit( buf: &'a [u8], depth: u32, ) -> Result<Self, DecodeError>
Decode a view with a custom recursion depth limit. Read more