pub struct SecuritySchemeView<'a> {
pub scheme: Option<SchemeView<'a>>,
pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}Fields
scheme: Option<SchemeView<'a>>__buffa_unknown_fields: UnknownFieldsView<'a>Trait Implementations
Sourceimpl<'a> Clone for SecuritySchemeView<'a>
impl<'a> Clone for SecuritySchemeView<'a>
Sourcefn clone(&self) -> SecuritySchemeView<'a>
fn clone(&self) -> SecuritySchemeView<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for SecuritySchemeView<'a>
impl<'a> Debug for SecuritySchemeView<'a>
Sourceimpl<'a> Default for SecuritySchemeView<'a>
impl<'a> Default for SecuritySchemeView<'a>
Sourcefn default() -> SecuritySchemeView<'a>
fn default() -> SecuritySchemeView<'a>
Returns the “default value” for a type. Read more
Sourceimpl DefaultViewInstance for SecuritySchemeView<'static>
impl DefaultViewInstance for SecuritySchemeView<'static>
Sourcefn default_view_instance() -> &'static Self
fn default_view_instance() -> &'static Self
Return a reference to the single default view instance.
Sourceimpl<'a> HasDefaultViewInstance for SecuritySchemeView<'a>
impl<'a> HasDefaultViewInstance for SecuritySchemeView<'a>
Sourcetype Static = SecuritySchemeView<'static>
type Static = SecuritySchemeView<'static>
The
'static instantiation of this view type.Sourcefn default_view_ptr() -> *const u8
fn default_view_ptr() -> *const u8
Return a pointer to the static default instance, erasing the
lifetime so it can be used for any
'a.Sourceimpl<'a> MessageView<'a> for SecuritySchemeView<'a>
impl<'a> MessageView<'a> for SecuritySchemeView<'a>
Sourcefn to_owned_message(&self) -> SecurityScheme
fn to_owned_message(&self) -> SecurityScheme
Convert this view to the owned message type.
Sourcetype Owned = SecurityScheme
type Owned = SecurityScheme
The corresponding owned message type.
Sourcefn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
fn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
Decode a view from a buffer, borrowing string/bytes fields directly. Read more
Sourcefn decode_view_with_limit(
buf: &'a [u8],
depth: u32,
) -> Result<Self, DecodeError>
fn decode_view_with_limit( buf: &'a [u8], depth: u32, ) -> Result<Self, DecodeError>
Decode a view with a custom recursion depth limit. Read more