pub struct TaskView<'a> {
pub id: &'a str,
pub context_id: &'a str,
pub status: MessageFieldView<TaskStatusView<'a>>,
pub artifacts: RepeatedView<'a, ArtifactView<'a>>,
pub history: RepeatedView<'a, MessageView<'a>>,
pub metadata: MessageFieldView<StructView<'a>>,
pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}Fields
id: &'a strField 1: id
context_id: &'a strField 2: context_id
status: MessageFieldView<TaskStatusView<'a>>Field 3: status
artifacts: RepeatedView<'a, ArtifactView<'a>>Field 4: artifacts
history: RepeatedView<'a, MessageView<'a>>Field 5: history
metadata: MessageFieldView<StructView<'a>>Field 6: metadata
__buffa_unknown_fields: UnknownFieldsView<'a>Trait Implementations
Sourceimpl DefaultViewInstance for TaskView<'static>
impl DefaultViewInstance for TaskView<'static>
Sourcefn default_view_instance() -> &'static Self
fn default_view_instance() -> &'static Self
Return a reference to the single default view instance.
Sourceimpl<'a> HasDefaultViewInstance for TaskView<'a>
impl<'a> HasDefaultViewInstance for TaskView<'a>
Sourceimpl<'a> MessageView<'a> for TaskView<'a>
impl<'a> MessageView<'a> for TaskView<'a>
Sourcefn to_owned_message(&self) -> Task
fn to_owned_message(&self) -> Task
Convert this view to the owned message type.
Sourcefn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
fn decode_view(buf: &'a [u8]) -> Result<Self, DecodeError>
Decode a view from a buffer, borrowing string/bytes fields directly. Read more
Sourcefn decode_view_with_limit(
buf: &'a [u8],
depth: u32,
) -> Result<Self, DecodeError>
fn decode_view_with_limit( buf: &'a [u8], depth: u32, ) -> Result<Self, DecodeError>
Decode a view with a custom recursion depth limit. Read more